@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import logging
 from markdown.inlinepatterns import Pattern
+import oembed
 
 
 LOG = logging.getLogger(__name__)
@@ -17,7 +18,17 @@ class OEmbedLinkPattern(Pattern):
         self.consumer = oembed_consumer
 
     def handleMatch(self, match):
-        url = match.group(3).strip()
-        response = self.consumer.embed(url)
-        placeholder = self.markdown.htmlStash.store(response['html'])
+        html = self.get_oembed_html_for_match(match)
+        if html is None:
+            return None
+        placeholder = self.markdown.htmlStash.store(html)
         return placeholder
+
+    def get_oembed_html_for_match(self, match):
+        url = match.group(3).strip()
+        try:
+            response = self.consumer.embed(url)
+        except oembed.OEmbedNoEndpoint:
+            return None
+        else:
+            return response['html']
